import sys
import typing

GenericType = typing.TypeVar("GenericType")


class ShaderImageTextureWrapper:
    NODES_LIST: typing.Any
    ''' '''

    colorspace_is_data: typing.Any
    ''' '''

    colorspace_name: typing.Any
    ''' '''

    extension: typing.Any
    ''' '''

    grid_row_diff: typing.Any
    ''' '''

    image: typing.Any
    ''' '''

    is_readonly: typing.Any
    ''' '''

    node_dst: typing.Any
    ''' '''

    node_image: typing.Any
    ''' '''

    node_mapping: typing.Any
    ''' '''

    owner_shader: typing.Any
    ''' '''

    projection: typing.Any
    ''' '''

    rotation: typing.Any
    ''' '''

    scale: typing.Any
    ''' '''

    socket_dst: typing.Any
    ''' '''

    texcoords: typing.Any
    ''' '''

    translation: typing.Any
    ''' '''

    use_alpha: typing.Any
    ''' '''

    def copy_from(self, tex):
        ''' 

        '''
        ...

    def copy_mapping_from(self, tex):
        ''' 

        '''
        ...

    def extension_get(self):
        ''' 

        '''
        ...

    def extension_set(self, extension):
        ''' 

        '''
        ...

    def has_mapping_node(self):
        ''' 

        '''
        ...

    def image_get(self):
        ''' 

        '''
        ...

    def image_set(self, image):
        ''' 

        '''
        ...

    def node_image_get(self):
        ''' 

        '''
        ...

    def node_mapping_get(self):
        ''' 

        '''
        ...

    def projection_get(self):
        ''' 

        '''
        ...

    def projection_set(self, projection):
        ''' 

        '''
        ...

    def rotation_get(self):
        ''' 

        '''
        ...

    def rotation_set(self, rotation):
        ''' 

        '''
        ...

    def scale_get(self):
        ''' 

        '''
        ...

    def scale_set(self, scale):
        ''' 

        '''
        ...

    def texcoords_get(self):
        ''' 

        '''
        ...

    def texcoords_set(self, texcoords):
        ''' 

        '''
        ...

    def translation_get(self):
        ''' 

        '''
        ...

    def translation_set(self, translation):
        ''' 

        '''
        ...


class ShaderWrapper:
    NODES_LIST: typing.Any
    ''' '''

    is_readonly: typing.Any
    ''' '''

    material: typing.Any
    ''' '''

    node_out: typing.Any
    ''' '''

    node_texcoords: typing.Any
    ''' '''

    use_nodes: typing.Any
    ''' '''

    def node_texcoords_get(self):
        ''' 

        '''
        ...

    def update(self):
        ''' 

        '''
        ...

    def use_nodes_get(self):
        ''' 

        '''
        ...

    def use_nodes_set(self, val):
        ''' 

        '''
        ...


class PrincipledBSDFWrapper(ShaderWrapper):
    NODES_LIST: typing.Any
    ''' '''

    alpha: typing.Any
    ''' '''

    alpha_texture: typing.Any
    ''' '''

    base_color: typing.Any
    ''' '''

    base_color_texture: typing.Any
    ''' '''

    emission_color: typing.Any
    ''' '''

    emission_color_texture: typing.Any
    ''' '''

    emission_strength: typing.Any
    ''' '''

    emission_strength_texture: typing.Any
    ''' '''

    ior: typing.Any
    ''' '''

    ior_texture: typing.Any
    ''' '''

    is_readonly: typing.Any
    ''' '''

    material: typing.Any
    ''' '''

    metallic: typing.Any
    ''' '''

    metallic_texture: typing.Any
    ''' '''

    node_normalmap: typing.Any
    ''' '''

    node_out: typing.Any
    ''' '''

    node_principled_bsdf: typing.Any
    ''' '''

    node_texcoords: typing.Any
    ''' '''

    normalmap_strength: typing.Any
    ''' '''

    normalmap_texture: typing.Any
    ''' '''

    roughness: typing.Any
    ''' '''

    roughness_texture: typing.Any
    ''' '''

    specular: typing.Any
    ''' '''

    specular_texture: typing.Any
    ''' '''

    specular_tint: typing.Any
    ''' '''

    specular_tint_texture: typing.Any
    ''' '''

    transmission: typing.Any
    ''' '''

    transmission_texture: typing.Any
    ''' '''

    use_nodes: typing.Any
    ''' '''

    def alpha_get(self):
        ''' 

        '''
        ...

    def alpha_set(self, value):
        ''' 

        '''
        ...

    def alpha_texture_get(self):
        ''' 

        '''
        ...

    def base_color_get(self):
        ''' 

        '''
        ...

    def base_color_set(self, color):
        ''' 

        '''
        ...

    def base_color_texture_get(self):
        ''' 

        '''
        ...

    def emission_color_get(self):
        ''' 

        '''
        ...

    def emission_color_set(self, color):
        ''' 

        '''
        ...

    def emission_color_texture_get(self):
        ''' 

        '''
        ...

    def emission_strength_get(self):
        ''' 

        '''
        ...

    def emission_strength_set(self, value):
        ''' 

        '''
        ...

    def emission_strength_texture_get(self):
        ''' 

        '''
        ...

    def ior_get(self):
        ''' 

        '''
        ...

    def ior_set(self, value):
        ''' 

        '''
        ...

    def ior_texture_get(self):
        ''' 

        '''
        ...

    def metallic_get(self):
        ''' 

        '''
        ...

    def metallic_set(self, value):
        ''' 

        '''
        ...

    def metallic_texture_get(self):
        ''' 

        '''
        ...

    def node_normalmap_get(self):
        ''' 

        '''
        ...

    def node_texcoords_get(self):
        ''' 

        '''
        ...

    def normalmap_strength_get(self):
        ''' 

        '''
        ...

    def normalmap_strength_set(self, value):
        ''' 

        '''
        ...

    def normalmap_texture_get(self):
        ''' 

        '''
        ...

    def roughness_get(self):
        ''' 

        '''
        ...

    def roughness_set(self, value):
        ''' 

        '''
        ...

    def roughness_texture_get(self):
        ''' 

        '''
        ...

    def specular_get(self):
        ''' 

        '''
        ...

    def specular_set(self, value):
        ''' 

        '''
        ...

    def specular_texture_get(self):
        ''' 

        '''
        ...

    def specular_tint_get(self):
        ''' 

        '''
        ...

    def specular_tint_set(self, color):
        ''' 

        '''
        ...

    def specular_tint_texture_get(self):
        ''' 

        '''
        ...

    def transmission_get(self):
        ''' 

        '''
        ...

    def transmission_set(self, value):
        ''' 

        '''
        ...

    def transmission_texture_get(self):
        ''' 

        '''
        ...

    def update(self):
        ''' 

        '''
        ...

    def use_nodes_get(self):
        ''' 

        '''
        ...

    def use_nodes_set(self, val):
        ''' 

        '''
        ...


def rgb_to_rgba(rgb):
    ''' 

    '''

    ...


def rgba_to_rgb(rgba):
    ''' 

    '''

    ...


def values_clamp(val, minv, maxv):
    ''' 

    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class NodeCategory:
    def poll(self, _context):
        ''' 

        '''
        ...


class NodeItem:
    label: typing.Any
    ''' '''

    translation_context: typing.Any
    ''' '''

    def draw(self, layout, _context):
        ''' 

        '''
        ...


class NodeItemCustom:
    ...


def draw_node_categories_menu(context):
    ''' 

    '''

    ...


def has_node_categories(context):
    ''' 

    '''

    ...


def node_categories_iter(context):
    ''' 

    '''

    ...


def node_items_iter(context):
    ''' 

    '''

    ...


def register_node_categories(identifier, cat_list):
    ''' 

    '''

    ...


def unregister_node_cat_types(cats):
    ''' 

    '''

    ...


def unregister_node_categories(identifier):
    ''' 

    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def add_scrollback(text, text_type):
    ''' 

    '''

    ...


def autocomplete(_context):
    ''' 

    '''

    ...


def banner(context):
    ''' 

    '''

    ...


def execute(context, _is_interactive):
    ''' 

    '''

    ...


def shell_run(text):
    ''' 

    '''

    ...



import sys
import typing
import bpy_types

GenericType = typing.TypeVar("GenericType")


class IndexSwitchItemAddOperator(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class IndexSwitchItemRemoveOperator(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class MoveModifierToNodes(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class NewGeometryNodeGroupTool(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class NewGeometryNodeTreeAssign(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class NewGeometryNodesModifier(bpy_types.Operator):
    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class ZoneItemAddOperator:
    active_index_name: typing.Any
    ''' '''

    default_socket_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    def execute(self, context):
        ''' 

        '''
        ...


class ZoneItemRemoveOperator:
    active_index_name: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    def execute(self, context):
        ''' 

        '''
        ...


class ZoneMoveItemOperator:
    active_index_name: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    def execute(self, context):
        ''' 

        '''
        ...


class ZoneOperator:
    def get_output_node(self, context):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...


class RepeatZoneOperator(ZoneOperator):
    active_index_name: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...


class SimulationZoneOperator(ZoneOperator):
    active_index_name: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...


class RepeatZoneItemAddOperator(RepeatZoneOperator, ZoneOperator,
                                ZoneItemAddOperator, bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    default_socket_type: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class RepeatZoneItemMoveOperator(RepeatZoneOperator, ZoneOperator,
                                 ZoneMoveItemOperator, bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class RepeatZoneItemRemoveOperator(RepeatZoneOperator, ZoneOperator,
                                   ZoneItemRemoveOperator, bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class SimulationZoneItemAddOperator(SimulationZoneOperator, ZoneOperator,
                                    ZoneItemAddOperator, bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    default_socket_type: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class SimulationZoneItemMoveOperator(SimulationZoneOperator, ZoneOperator,
                                     ZoneMoveItemOperator, bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class SimulationZoneItemRemoveOperator(SimulationZoneOperator, ZoneOperator,
                                       ZoneItemRemoveOperator,
                                       bpy_types.Operator):
    active_index_name: typing.Any
    ''' '''

    bl_idname: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    input_node_type: typing.Any
    ''' '''

    items_name: typing.Any
    ''' '''

    output_node_type: typing.Any
    ''' '''

    def as_keywords(self, ignore):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def execute(self, context):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def get_output_node(self, context):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def poll_message_set(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


def add_empty_geometry_node_group(name):
    ''' 

    '''

    ...


def edit_geometry_nodes_modifier_poll(context):
    ''' 

    '''

    ...


def geometry_modifier_poll(context):
    ''' 

    '''

    ...


def geometry_node_group_empty_modifier_new(name):
    ''' 

    '''

    ...


def geometry_node_group_empty_new(name):
    ''' 

    '''

    ...


def geometry_node_group_empty_tool_new(context):
    ''' 

    '''

    ...


def get_context_modifier(context):
    ''' 

    '''

    ...


def get_enabled_socket_with_name(sockets, name):
    ''' 

    '''

    ...


def get_socket_with_identifier(sockets, identifier):
    ''' 

    '''

    ...


def modifier_attribute_name_get(modifier, identifier):
    ''' 

    '''

    ...


def modifier_input_use_attribute(modifier, identifier):
    ''' 

    '''

    ...


def socket_idname_to_attribute_type(idname):
    ''' 

    '''

    ...



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


def bake_to_keyframes(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        frame_start: typing.Optional[typing.Any] = 1,
        frame_end: typing.Optional[typing.Any] = 250,
        step: typing.Optional[typing.Any] = 1):
    ''' Bake rigid body transformations of selected objects to keyframes :File: `startup/bl_operators/rigidbody.py\:108 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/rigidbody.py#L108>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param frame_start: Start Frame, Start frame for baking
    :type frame_start: typing.Optional[typing.Any]
    :param frame_end: End Frame, End frame for baking
    :type frame_end: typing.Optional[typing.Any]
    :param step: Frame Step, Frame Step
    :type step: typing.Optional[typing.Any]
    '''

    ...


def connect(override_context: typing.Optional[
        typing.Union[typing.Dict, 'bpy.types.Context']] = None,
            execution_context: typing.Optional[typing.Union[str, int]] = None,
            undo: typing.Optional[bool] = None,
            *,
            con_type: typing.Optional[typing.Any] = 'FIXED',
            pivot_type: typing.Optional[typing.Any] = 'CENTER',
            connection_pattern: typing.Optional[typing.
                                                Any] = 'SELECTED_TO_ACTIVE'):
    ''' Create rigid body constraints between selected rigid bodies :File: `startup/bl_operators/rigidbody.py\:270 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/rigidbody.py#L270>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param con_type: Type, Type of generated constraint * ``FIXED`` Fixed -- Glue rigid bodies together. * ``POINT`` Point -- Constrain rigid bodies to move around common pivot point. * ``HINGE`` Hinge -- Restrict rigid body rotation to one axis. * ``SLIDER`` Slider -- Restrict rigid body translation to one axis. * ``PISTON`` Piston -- Restrict rigid body translation and rotation to one axis. * ``GENERIC`` Generic -- Restrict translation and rotation to specified axes. * ``GENERIC_SPRING`` Generic Spring -- Restrict translation and rotation to specified axes with springs. * ``MOTOR`` Motor -- Drive rigid body around or along an axis.
    :type con_type: typing.Optional[typing.Any]
    :param pivot_type: Location, Constraint pivot location * ``CENTER`` Center -- Pivot location is between the constrained rigid bodies. * ``ACTIVE`` Active -- Pivot location is at the active object position. * ``SELECTED`` Selected -- Pivot location is at the selected object position.
    :type pivot_type: typing.Optional[typing.Any]
    :param connection_pattern: Connection Pattern, Pattern used to connect objects * ``SELECTED_TO_ACTIVE`` Selected to Active -- Connect selected objects to the active object. * ``CHAIN_DISTANCE`` Chain by Distance -- Connect objects as a chain based on distance, starting at the active object.
    :type connection_pattern: typing.Optional[typing.Any]
    '''

    ...


def constraint_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'FIXED'):
    ''' Add Rigid Body Constraint to active object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Rigid Body Constraint Type
    :type type: typing.Optional[typing.Union[str, int]]
    '''

    ...


def constraint_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove Rigid Body Constraint from Object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def mass_calculate(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        material: typing.Optional[typing.Union[str, int, typing.
                                               Any]] = 'DEFAULT',
        density: typing.Optional[typing.Any] = 1.0):
    ''' Automatically calculate mass values for Rigid Body Objects based on volume

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param material: Material Preset, Type of material that objects are made of (determines material density)
    :type material: typing.Optional[typing.Union[str, int, typing.Any]]
    :param density: Density, Density value (kg/m^3), allows custom value if the 'Custom' preset is used
    :type density: typing.Optional[typing.Any]
    '''

    ...


def object_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'ACTIVE'):
    ''' Add active object as Rigid Body

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Rigid Body Type
    :type type: typing.Optional[typing.Union[str, int]]
    '''

    ...


def object_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove Rigid Body settings from Object

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def object_settings_copy(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Copy Rigid Body settings from active object to selected :File: `startup/bl_operators/rigidbody.py\:45 <https://projects.blender.org/blender/blender/src/branch/main/scripts/startup/bl_operators/rigidbody.py#L45>`__

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def objects_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'ACTIVE'):
    ''' Add selected objects as Rigid Bodies

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Rigid Body Type
    :type type: typing.Optional[typing.Union[str, int]]
    '''

    ...


def objects_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove selected objects from Rigid Body simulation

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def shape_change(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None,
        *,
        type: typing.Optional[typing.Union[str, int]] = 'MESH'):
    ''' Change collision shapes for selected Rigid Body Objects

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    :param type: Rigid Body Shape
    :type type: typing.Optional[typing.Union[str, int]]
    '''

    ...


def world_add(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Add Rigid Body simulation world to the current scene

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...


def world_remove(
        override_context: typing.Optional[
            typing.Union[typing.Dict, 'bpy.types.Context']] = None,
        execution_context: typing.Optional[typing.Union[str, int]] = None,
        undo: typing.Optional[bool] = None):
    ''' Remove Rigid Body simulation world from the current scene

    :type override_context: typing.Optional[typing.Union[typing.Dict, 'bpy.types.Context']]
    :type execution_context: typing.Optional[typing.Union[str, int]]
    :type undo: typing.Optional[bool]
    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class MotionPathButtonsPanel:
    bl_label: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    def draw_settings(self, _context, avs, mpath, bones):
        ''' 

        '''
        ...


class MotionPathButtonsPanel_display:
    bl_label: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    def draw_settings(self, _context, avs, mpath, bones):
        ''' 

        '''
        ...



import sys
import typing
import bpy_types
import rna_prop_ui

GenericType = typing.TypeVar("GenericType")


class WorkSpaceButtonsPanel:
    bl_category: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''


class WORKSPACE_PT_addons(WorkSpaceButtonsPanel, bpy_types.Panel,
                          bpy_types._GenericUI):
    bl_category: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_parent_id: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def append(self, draw_func):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def draw(self, context):
        ''' 

        '''
        ...

    def draw_header(self, context):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_extended(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def prepend(self, draw_func):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def remove(self, draw_func):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class WORKSPACE_PT_custom_props(WorkSpaceButtonsPanel,
                                rna_prop_ui.PropertyPanel, bpy_types.Panel,
                                bpy_types._GenericUI):
    bl_category: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_order: typing.Any
    ''' '''

    bl_parent_id: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def append(self, draw_func):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def draw(self, context):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_extended(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def prepend(self, draw_func):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def remove(self, draw_func):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...


class WORKSPACE_PT_main(WorkSpaceButtonsPanel, bpy_types.Panel,
                        bpy_types._GenericUI):
    bl_category: typing.Any
    ''' '''

    bl_label: typing.Any
    ''' '''

    bl_options: typing.Any
    ''' '''

    bl_region_type: typing.Any
    ''' '''

    bl_rna: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    id_data: typing.Any
    ''' '''

    def append(self, draw_func):
        ''' 

        '''
        ...

    def as_pointer(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass(self):
        ''' 

        '''
        ...

    def bl_rna_get_subclass_py(self):
        ''' 

        '''
        ...

    def draw(self, context):
        ''' 

        '''
        ...

    def driver_add(self):
        ''' 

        '''
        ...

    def driver_remove(self):
        ''' 

        '''
        ...

    def get(self):
        ''' 

        '''
        ...

    def id_properties_clear(self):
        ''' 

        '''
        ...

    def id_properties_ensure(self):
        ''' 

        '''
        ...

    def id_properties_ui(self):
        ''' 

        '''
        ...

    def is_extended(self):
        ''' 

        '''
        ...

    def is_property_hidden(self):
        ''' 

        '''
        ...

    def is_property_overridable_library(self):
        ''' 

        '''
        ...

    def is_property_readonly(self):
        ''' 

        '''
        ...

    def is_property_set(self):
        ''' 

        '''
        ...

    def items(self):
        ''' 

        '''
        ...

    def keyframe_delete(self):
        ''' 

        '''
        ...

    def keyframe_insert(self):
        ''' 

        '''
        ...

    def keys(self):
        ''' 

        '''
        ...

    def path_from_id(self):
        ''' 

        '''
        ...

    def path_resolve(self):
        ''' 

        '''
        ...

    def pop(self):
        ''' 

        '''
        ...

    def prepend(self, draw_func):
        ''' 

        '''
        ...

    def property_overridable_library_set(self):
        ''' 

        '''
        ...

    def property_unset(self):
        ''' 

        '''
        ...

    def remove(self, draw_func):
        ''' 

        '''
        ...

    def type_recast(self):
        ''' 

        '''
        ...

    def values(self):
        ''' 

        '''
        ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class AssetBrowserPanel:
    bl_space_type: typing.Any
    ''' '''

    def asset_browser_panel_poll(self, context):
        ''' 

        '''
        ...

    def poll(self, context):
        ''' 

        '''
        ...


class AssetMetaDataPanel:
    bl_region_type: typing.Any
    ''' '''

    bl_space_type: typing.Any
    ''' '''

    def poll(self, context):
        ''' 

        '''
        ...


class SpaceAssetInfo:
    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


def activate(template_id, reload_scripts):
    ''' 

    '''

    ...


def import_from_id(template_id, ignore_not_found):
    ''' 

    '''

    ...


def import_from_path(path, ignore_not_found):
    ''' 

    '''

    ...


def reset(reload_scripts):
    ''' 

    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class _TokenizeDataPath:
    data_path: typing.Any
    ''' '''


def decompose_data_path(data_path):
    ''' 

    '''

    ...


def property_definition_from_data_path(base, data_path):
    ''' 

    '''

    ...



import sys
import typing
import bpy.types

GenericType = typing.TypeVar("GenericType")


class BakeOptions:
    ...


class KeyframesCo:
    keyframes_from_fcurve: typing.Any
    ''' '''

    def add_paths(self, rna_path, total_indices):
        ''' 

        '''
        ...

    def extend_co_value(self, rna_path, frame, value):
        ''' 

        '''
        ...

    def extend_co_values(self, rna_path, total_indices, frame, values):
        ''' 

        '''
        ...

    def insert_keyframes_into_existing_action(
            self, lookup_fcurves, total_new_keys, action, action_group_name):
        ''' 

        '''
        ...

    def insert_keyframes_into_new_action(self, total_new_keys, action,
                                         action_group_name):
        ''' 

        '''
        ...


def bake_action(obj: 'bpy.types.Object', *,
                action: typing.Optional['bpy.types.Action'], frames: int,
                bake_o) -> 'bpy.types.Action':
    ''' 

    :param obj: Object to bake.
    :type obj: 'bpy.types.Object'
    :param action: An action to bake the data into, or None for a new action to be created.
    :type action: typing.Optional['bpy.types.Action']
    :param frames: Frames to bake.
    :type frames: int
    :rtype: 'bpy.types.Action'
    :return: an action or None
    '''

    ...


def bake_action_iter(obj: 'bpy.types.Object', *,
                     action: typing.Optional['bpy.types.Action'],
                     bake_o) -> 'bpy.types.Action':
    ''' An coroutine that bakes action for a single object.

    :param obj: Object to bake.
    :type obj: 'bpy.types.Object'
    :param action: An action to bake the data into, or None for a new action to be created.
    :type action: typing.Optional['bpy.types.Action']
    :param bake_options: Boolean options of what to include into the action bake.
    :type bake_options: typing.Any
    :rtype: 'bpy.types.Action'
    :return: an action or None
    '''

    ...


def bake_action_objects(object_action_pairs, *, frames: int,
                        bake_o) -> typing.Iterable['bpy.types.Action']:
    ''' A version of :func:`bake_action_objects_iter` that takes frames and returns the output.

    :param frames: Frames to bake.
    :type frames: int
    :rtype: typing.Iterable['bpy.types.Action']
    :return: A sequence of Action or None types (aligned with `object_action_pairs`)
    '''

    ...


def bake_action_objects_iter(
        object_action_pairs: typing.
        Union['bpy.types.Object', 'bpy.types.Sequence', 'bpy.types.Action'],
        bake_o):
    ''' An coroutine that bakes actions for multiple objects.

    :param object_action_pairs: Sequence of object action tuples, action is the destination for the baked data. When None a new action will be created.
    :type object_action_pairs: typing.Union['bpy.types.Object', 'bpy.types.Sequence', 'bpy.types.Action']
    '''

    ...



import sys
import typing

GenericType = typing.TypeVar("GenericType")


class AppOverrideState:
    addon_paths: typing.Any
    ''' '''

    addons: typing.Any
    ''' '''

    class_ignore: typing.Any
    ''' '''

    ui_ignore_classes: typing.Any
    ''' '''

    ui_ignore_label: typing.Any
    ''' '''

    ui_ignore_menu: typing.Any
    ''' '''

    ui_ignore_operator: typing.Any
    ''' '''

    ui_ignore_property: typing.Any
    ''' '''

    def setup(self):
        ''' 

        '''
        ...

    def teardown(self):
        ''' 

        '''
        ...
